@@ -25,44 +25,39 @@ class AddLiveStreamTranscodeRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'live', '2016-11-01', 'AddLiveStreamTranscode','live')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Template(self):
+	def get_Template(self): # String
 		return self.get_query_params().get('Template')
 
-	def set_Template(self,Template):
-		self.add_query_param('Template',Template)
-
-	def get_Lazy(self):
+	def set_Template(self, Template):  # String
+		self.add_query_param('Template', Template)
+	def get_Lazy(self): # String
 		return self.get_query_params().get('Lazy')
 
-	def set_Lazy(self,Lazy):
-		self.add_query_param('Lazy',Lazy)
-
-	def get_App(self):
+	def set_Lazy(self, Lazy):  # String
+		self.add_query_param('Lazy', Lazy)
+	def get_App(self): # String
 		return self.get_query_params().get('App')
 
-	def set_App(self,App):
-		self.add_query_param('App',App)
-
-	def get_EncryptParameters(self):
+	def set_App(self, App):  # String
+		self.add_query_param('App', App)
+	def get_EncryptParameters(self): # String
 		return self.get_query_params().get('EncryptParameters')
 
-	def set_EncryptParameters(self,EncryptParameters):
-		self.add_query_param('EncryptParameters',EncryptParameters)
-
-	def get_OwnerId(self):
+	def set_EncryptParameters(self, EncryptParameters):  # String
+		self.add_query_param('EncryptParameters', EncryptParameters)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_Domain(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_Domain(self): # String
 		return self.get_query_params().get('Domain')
 
-	def set_Domain(self,Domain):
-		self.add_query_param('Domain',Domain)
\ No newline at end of file
+	def set_Domain(self, Domain):  # String
+		self.add_query_param('Domain', Domain)
